# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.

    The version of the OpenAPI document: 1.0
    Contact: dev@robustintelligence.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ri.apiclient.models.generative_testing_result_example import GenerativeTestingResultExample
from ri.apiclient.models.generative_testing_result_standard_info import GenerativeTestingResultStandardInfo
from ri.apiclient.models.generativevalidation_objective_sub_category import GenerativevalidationObjectiveSubCategory
from ri.apiclient.models.generativevalidation_threat import GenerativevalidationThreat
from ri.apiclient.models.libgenerative_severity import LibgenerativeSeverity
from ri.apiclient.models.rime_attack_objective import RimeAttackObjective
from ri.apiclient.models.rime_uuid import RimeUUID
from typing import Optional, Set
from typing_extensions import Self

class GenerativevalidationGenerativeTestingResult(BaseModel):
    """
    GenerativeTestingResult represents a single result of testing a Generative model with attack prompts. The model output is sent to a detection layer, which indicates whether it contains objectionable content. There is a single test result for the \"attack_technique\", \"attack_objective\", and \"objective_sub_category\" combination.
    """ # noqa: E501
    id: Optional[RimeUUID] = None
    job_id: Optional[RimeUUID] = Field(default=None, alias="jobId")
    attack_technique: Optional[StrictStr] = Field(default=None, description="The attack technique used in the prompt. This is a string because the types of attacks changes frequently over time depending on our threat intelligence.", alias="attackTechnique")
    attack_objective: Optional[RimeAttackObjective] = Field(default=None, alias="attackObjective")
    objective_sub_category: Optional[GenerativevalidationObjectiveSubCategory] = Field(default=None, alias="objectiveSubCategory")
    failing_examples: Optional[List[GenerativeTestingResultExample]] = Field(default=None, description="List of failing examples to demonstrate failures in this category.", alias="failingExamples")
    severity: Optional[LibgenerativeSeverity] = None
    owasp_standards: Optional[List[GenerativeTestingResultStandardInfo]] = Field(default=None, description="List of the OWASP AI risk standards associated with the attacks in these results.", alias="owaspStandards")
    nist_standards: Optional[List[GenerativeTestingResultStandardInfo]] = Field(default=None, description="List of the NIST AI risk standards associated with the attacks in these results.", alias="nistStandards")
    mitre_standards: Optional[List[GenerativeTestingResultStandardInfo]] = Field(default=None, description="List of the MITRE AI risk standards associated with the attacks in these results.", alias="mitreStandards")
    attacks_attempted: Optional[StrictInt] = Field(default=None, description="The number of attacks attempted for these results.", alias="attacksAttempted")
    threat: Optional[GenerativevalidationThreat] = None
    successful_attacks: Optional[StrictInt] = Field(default=None, description="The number of successful attacks completed for these results.", alias="successfulAttacks")
    skipped_reason: Optional[StrictStr] = Field(default=None, description="Indicates that the test was skipped and provides a reason. If the test was not skipped this will be the empty string.", alias="skippedReason")
    generative_validation_test_run_id: Optional[RimeUUID] = Field(default=None, alias="generativeValidationTestRunId")
    __properties: ClassVar[List[str]] = ["id", "jobId", "attackTechnique", "attackObjective", "objectiveSubCategory", "failingExamples", "severity", "owaspStandards", "nistStandards", "mitreStandards", "attacksAttempted", "threat", "successfulAttacks", "skippedReason", "generativeValidationTestRunId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GenerativevalidationGenerativeTestingResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of id
        if self.id:
            _dict['id'] = self.id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of job_id
        if self.job_id:
            _dict['jobId'] = self.job_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in failing_examples (list)
        _items = []
        if self.failing_examples:
            for _item in self.failing_examples:
                if _item:
                    _items.append(_item.to_dict())
            _dict['failingExamples'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in owasp_standards (list)
        _items = []
        if self.owasp_standards:
            for _item in self.owasp_standards:
                if _item:
                    _items.append(_item.to_dict())
            _dict['owaspStandards'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in nist_standards (list)
        _items = []
        if self.nist_standards:
            for _item in self.nist_standards:
                if _item:
                    _items.append(_item.to_dict())
            _dict['nistStandards'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in mitre_standards (list)
        _items = []
        if self.mitre_standards:
            for _item in self.mitre_standards:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mitreStandards'] = _items
        # override the default output from pydantic by calling `to_dict()` of generative_validation_test_run_id
        if self.generative_validation_test_run_id:
            _dict['generativeValidationTestRunId'] = self.generative_validation_test_run_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GenerativevalidationGenerativeTestingResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": RimeUUID.from_dict(obj["id"]) if obj.get("id") is not None else None,
            "jobId": RimeUUID.from_dict(obj["jobId"]) if obj.get("jobId") is not None else None,
            "attackTechnique": obj.get("attackTechnique"),
            "attackObjective": obj.get("attackObjective"),
            "objectiveSubCategory": obj.get("objectiveSubCategory"),
            "failingExamples": [GenerativeTestingResultExample.from_dict(_item) for _item in obj["failingExamples"]] if obj.get("failingExamples") is not None else None,
            "severity": obj.get("severity"),
            "owaspStandards": [GenerativeTestingResultStandardInfo.from_dict(_item) for _item in obj["owaspStandards"]] if obj.get("owaspStandards") is not None else None,
            "nistStandards": [GenerativeTestingResultStandardInfo.from_dict(_item) for _item in obj["nistStandards"]] if obj.get("nistStandards") is not None else None,
            "mitreStandards": [GenerativeTestingResultStandardInfo.from_dict(_item) for _item in obj["mitreStandards"]] if obj.get("mitreStandards") is not None else None,
            "attacksAttempted": obj.get("attacksAttempted"),
            "threat": obj.get("threat"),
            "successfulAttacks": obj.get("successfulAttacks"),
            "skippedReason": obj.get("skippedReason"),
            "generativeValidationTestRunId": RimeUUID.from_dict(obj["generativeValidationTestRunId"]) if obj.get("generativeValidationTestRunId") is not None else None
        })
        return _obj


